You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@apr.apache.org by co...@apache.org on 2005/10/18 17:14:49 UTC

svn commit: r326119 - /apr/apr/trunk/include/arch/netware/apr_arch_file_io.h

Author: colm
Date: Tue Oct 18 08:14:44 2005
New Revision: 326119

URL: http://svn.apache.org/viewcvs?rev=326119&view=rev
Log:
Initial implementation of variable file-io buffer sizes on the Netware 
platform; partially guesswork based - untested.

Modified:
    apr/apr/trunk/include/arch/netware/apr_arch_file_io.h

Modified: apr/apr/trunk/include/arch/netware/apr_arch_file_io.h
URL: http://svn.apache.org/viewcvs/apr/apr/trunk/include/arch/netware/apr_arch_file_io.h?rev=326119&r1=326118&r2=326119&view=diff
==============================================================================
--- apr/apr/trunk/include/arch/netware/apr_arch_file_io.h (original)
+++ apr/apr/trunk/include/arch/netware/apr_arch_file_io.h Tue Oct 18 08:14:44 2005
@@ -69,7 +69,9 @@
 
 /* End System headers */
 
-#define APR_FILE_BUFSIZE 4096
+#define APR_FILE_DEFAULT_BUFSIZE 4096
+/* For backwards compat */
+#define APR_FILE_BUFSIZE APR_FILE_DEFAULT_BUFSIZE
 
 #if APR_HAS_LARGE_FILES
 #define lseek(f,o,w) lseek64(f,o,w)
@@ -95,7 +97,8 @@
 
     /* Stuff for buffered mode */
     char *buffer;
-    int bufpos;               /* Read/Write position in buffer */
+    apr_size_t bufpos;    /* Read/Write position in buffer */
+    apr_size_t bufsize;   /* The buffer size */
     apr_off_t dataRead;   /* amount of valid data read into buffer */
     int direction;            /* buffer being used for 0 = read, 1 = write */
     apr_off_t filePtr;    /* position in file of handle */